"""OntoSight - Interactive visualization library for knowledge graphs and structured data.

A simple, powerful library for creating interactive visualizations of graphs,
trees, lists, and other structured data with Python.
"""

from ontosight.core import (
    view_graph,
    view_hypergraph,
    view_nodes,
)

__version__ = "0.1.3"
__author__ = "Yifan Feng"
__email__ = "evanfeng97@gmail.com"

__all__ = [
    "view_graph",
    "view_hypergraph",
    "view_nodes",
]
